==> haskell-warp-tls-3.4.9-127-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-warp-tls.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 warp-tls
version:              3.4.9
visibility:           public
id:                   warp-tls-3.4.9-1HaLpcwL0nZKnAJhzObRMJ
key:                  warp-tls-3.4.9-1HaLpcwL0nZKnAJhzObRMJ
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             HTTP over TLS support for Warp via the TLS package
description:
    SSLv1 and SSLv2 are obsoleted by IETF.
    We should use TLS 1.2 (or TLS 1.1 or TLS 1.0 if necessary).
    HTTP/2 can be negotiated by ALPN.
    API docs and the README are available at
    <http://www.stackage.org/package/warp-tls>.

category:             Web, Yesod
abi:                  3e12a2cc60cd0a98508faf278252dfd5
exposed:              True
exposed-modules:
    Network.Wai.Handler.WarpTLS Network.Wai.Handler.WarpTLS.Internal

import-dirs:          /usr/lib/ghc-9.4.8/site-local/warp-tls-3.4.9
library-dirs:         /usr/lib/ghc-9.4.8/site-local/warp-tls-3.4.9
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/warp-tls-3.4.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-warp-tls
hs-libraries:         HSwarp-tls-3.4.9-1HaLpcwL0nZKnAJhzObRMJ
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    data-default-0.7.1.2-8yRIq8kwMNHG7OFJsT5Ayy
    network-3.1.4.0-KmVGd8MQrab5lGMy9eMLcZ
    recv-0.1.1-4Z47iRF1UGyBytuvYfWdRs
    streaming-commons-0.2.3.0-K61X0gown8RJ3nxox6FRzl
    tls-2.0.6-8idxXgkQAZMLy6JTSsAchb
    tls-session-manager-0.0.5-2KQk7LDgD07BX4WqljeOgj
    unliftio-0.2.25.1-7dVF98U9KQcKhx4RI2aKTx
    wai-3.2.4-JYES4h2pzGv7ciJ8Xc4lzy warp-3.3.30-1d6vGs6WRyG5v9ZRSP283B

haddock-interfaces:   /usr/share/doc/haskell-warp-tls/html/warp-tls.haddock
haddock-html:         /usr/share/doc/haskell-warp-tls/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-warp-tls-3.4.9-128-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-warp-tls.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 warp-tls
version:              3.4.9
visibility:           public
id:                   warp-tls-3.4.9-Fp0B89LJmz5DOBxCciSNo9
key:                  warp-tls-3.4.9-Fp0B89LJmz5DOBxCciSNo9
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             HTTP over TLS support for Warp via the TLS package
description:
    SSLv1 and SSLv2 are obsoleted by IETF.
    We should use TLS 1.2 (or TLS 1.1 or TLS 1.0 if necessary).
    HTTP/2 can be negotiated by ALPN.
    API docs and the README are available at
    <http://www.stackage.org/package/warp-tls>.

category:             Web, Yesod
abi:                  ba5be15041e444e8ceba7c99bfd4bbde
exposed:              True
exposed-modules:
    Network.Wai.Handler.WarpTLS Network.Wai.Handler.WarpTLS.Internal

import-dirs:          /usr/lib/ghc-9.4.8/site-local/warp-tls-3.4.9
library-dirs:         /usr/lib/ghc-9.4.8/site-local/warp-tls-3.4.9
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/warp-tls-3.4.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-warp-tls
hs-libraries:         HSwarp-tls-3.4.9-Fp0B89LJmz5DOBxCciSNo9
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    data-default-0.7.1.2-8yRIq8kwMNHG7OFJsT5Ayy
    network-3.1.4.0-9ZkyLgutzTZFWrHs4BgIgX
    recv-0.1.1-ABxxXinbSNQKoxUhQYQl4D
    streaming-commons-0.2.3.0-GROQORqjjU1AlDKJpV35uv
    tls-2.0.6-CSJYPTOLv792zYQ8qeww7Y
    tls-session-manager-0.0.5-A4U2vEU1PssDzdHefpkY2o
    unliftio-0.2.25.1-HM0R1ty4e2TDt6fGDzBedX
    wai-3.2.4-1yop7BvplydTH1djBo1do warp-3.3.30-8OpZYlaRw56DjKQnzqAXnQ

haddock-interfaces:   /usr/share/doc/haskell-warp-tls/html/warp-tls.haddock
haddock-html:         /usr/share/doc/haskell-warp-tls/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
